@@ -1,7 +1,8 @@
 int myrand(int max);
 void * mymalloc(int size, char *what);
 void * myrealloc(void *oldp, int newsize, char *what);
-char * mystrdup(char *in);
+void myfree(void *p);
+char * mystrdup(char *in, char *what);
 char * read_line_fd(int fd);
 char * get_load(void);
 int get_vmsize(pid_t pid);
@@ -14,6 +15,9 @@ char check_date(void);
 ssize_t WRITE(int fd, char *whereto, size_t len);
 char * amount_to_str(int amount);
 char * replace_string(char *in, int pos_start, int pos_end, char *with_what);
+struct passwd *getuserinfo(void);
+int myopen(char *path, int mode);
+int myclose(int fd);
 
 #define min(x, y) ((x)<(y)?(x):(y))
 #define max(x, y) ((x)>(y)?(x):(y))
